FileSystemEntity class abstract

The common super class for io.File, io.Directory, and io.Link objects.

Implemented types
Implementers

Constructors

FileSystemEntity()

Properties

absolute → FileSystemEntity
A FileSystemEntity whose path is the absolute path of path.
no setterinherited
basename → String
Gets the part of this entity's path after the last separator.
no setter
dirname → String
Gets the part of this entity's path before the last separator.
no setter
fileSystem → FileSystem
Returns the file system responsible for this entity.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isAbsolute → bool
Whether this object's path is absolute.
no setterinherited
parent → Directory
The parent directory of this entity.
no setteroverride
path → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
A Uri representing the file system entity's location.
no setterinherited

Methods

delete({bool recursive = false}) → Future<FileSystemEntity>
Deletes this FileSystemEntity.
override
deleteSync({bool recursive = false}) → void
Synchronously deletes this FileSystemEntity.
inherited
exists() → Future<bool>
Checks whether the file system entity with this path exists.
inherited
existsSync() → bool
Synchronously checks whether the file system entity with this path exists.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rename(String newPath) → Future<FileSystemEntity>
Renames this file system entity.
inherited
renameSync(String newPath) → FileSystemEntity
Synchronously renames this file system entity.
inherited
Resolves the path of a file system object relative to the current working directory.
inherited
resolveSymbolicLinksSync() → String
Resolves the path of a file system object relative to the current working directory.
inherited
stat() → Future<FileStat>
Calls the operating system's stat() function on path.
inherited
statSync() → FileStat
Synchronously calls the operating system's stat() function on path.
inherited
toString() → String
A string representation of this object.
inherited
watch({int events = FileSystemEvent.all, bool recursive = false}) → Stream<FileSystemEvent>
Start watching the FileSystemEntity for changes.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited